==> jupyterlab_myst-1.0.1.tar.gz: jupyterlab_myst-1.0.1/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.0.1

([Full Changelog](https://github.com/executablebooks/jupyterlab-myst/compare/v1.0.0...d266dab97266eefc69ad30ffc151664b928c8d00))

### Bugs fixed

- fix: use selector for JupyterLab dark mode [#85](https://github.com/executablebooks/jupyterlab-myst/pull/85) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/executablebooks/jupyterlab-myst/graphs/contributors?from=2023-02-12&to=2023-02-15&type=c))

[@agoose77](https://github.com/search?q=repo%3Aexecutablebooks%2Fjupyterlab-myst+involves%3Aagoose77+updated%3A2023-02-12..2023-02-15&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Aexecutablebooks%2Fjupyterlab-myst+involves%3Agithub-actions+updated%3A2023-02-12..2023-02-15&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## v1.0.0 - 2023/02/11

Merge and release the next version of jupyterlab-myst as a major version bump! 🚀
See [](https://github.com/executablebooks/jupyterlab-myst/issues/57) for discussion.

---

# `jupyterlab-mystjs`

Merge the repositories of `jupyterlab-mystjs` and `jupyterlab-myst` together.

### v0.1.4

Support legacy mode to open with the myst renderer or the original notebook with a right click.

### v0.1.3

Support local images and links, for example, opening a link to another notebook.

### v0.1.2

Use `@myst-theme` components from NPM.

---

## `jupyterlab-mystjs`

This project was merged with the original version, based on `jupyterlab-markup`,
the release history can be found on the [`v0 branch`](https://github.com/executablebooks/jupyterlab-myst/tree/v0).

### v0.1.7 - pre-release

Support for sphinx math, eval inline directives for inline execution.

### v0.1.6

Last stable release of `jupyterlab-myst` based on `markdown-it` and `jupyterlab-markup`.

==> jupyterlab_myst-1.1.0.tar.gz: jupyterlab_myst-1.1.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.1.0

([Full Changelog](https://github.com/executablebooks/jupyterlab-myst/compare/v1.0.1...35226db9d5292496312f5566479a0fee206e8e38))

### Enhancements made

- 🤩 Inline expressions [#92](https://github.com/executablebooks/jupyterlab-myst/pull/92) ([@rowanc1](https://github.com/rowanc1))
- 👩🏻‍🎨 Improve myst styles [#91](https://github.com/executablebooks/jupyterlab-myst/pull/91) ([@rowanc1](https://github.com/rowanc1))
- 🧜‍♀️ Upgrade to new MyST markdown parsers [#88](https://github.com/executablebooks/jupyterlab-myst/pull/88) ([@rowanc1](https://github.com/rowanc1))

### Bugs fixed

- 🐛 Show citations with an error [#93](https://github.com/executablebooks/jupyterlab-myst/pull/93) ([@rowanc1](https://github.com/rowanc1))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/executablebooks/jupyterlab-myst/graphs/contributors?from=2023-02-15&to=2023-02-22&type=c))

[@github-actions](https://github.com/search?q=repo%3Aexecutablebooks%2Fjupyterlab-myst+involves%3Agithub-actions+updated%3A2023-02-15..2023-02-22&type=Issues) | [@rowanc1](https://github.com/search?q=repo%3Aexecutablebooks%2Fjupyterlab-myst+involves%3Arowanc1+updated%3A2023-02-15..2023-02-22&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.0.1

([Full Changelog](https://github.com/executablebooks/jupyterlab-myst/compare/v1.0.0...d266dab97266eefc69ad30ffc151664b928c8d00))

### Bugs fixed

- fix: use selector for JupyterLab dark mode [#85](https://github.com/executablebooks/jupyterlab-myst/pull/85) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/executablebooks/jupyterlab-myst/graphs/contributors?from=2023-02-12&to=2023-02-15&type=c))

[@agoose77](https://github.com/search?q=repo%3Aexecutablebooks%2Fjupyterlab-myst+involves%3Aagoose77+updated%3A2023-02-12..2023-02-15&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Aexecutablebooks%2Fjupyterlab-myst+involves%3Agithub-actions+updated%3A2023-02-12..2023-02-15&type=Issues)

## v1.0.0 - 2023/02/11

Merge and release the next version of jupyterlab-myst as a major version bump! 🚀
See [](https://github.com/executablebooks/jupyterlab-myst/issues/57) for discussion.

---

# `jupyterlab-mystjs`

Merge the repositories of `jupyterlab-mystjs` and `jupyterlab-myst` together.

### v0.1.4

Support legacy mode to open with the myst renderer or the original notebook with a right click.

### v0.1.3

Support local images and links, for example, opening a link to another notebook.

### v0.1.2

Use `@myst-theme` components from NPM.

---

## `jupyterlab-mystjs`

This project was merged with the original version, based on `jupyterlab-markup`,
the release history can be found on the [`v0 branch`](https://github.com/executablebooks/jupyterlab-myst/tree/v0).

### v0.1.7 - pre-release

Support for sphinx math, eval inline directives for inline execution.

### v0.1.6

Last stable release of `jupyterlab-myst` based on `markdown-it` and `jupyterlab-markup`.
